=== renamed file 'plainbox/.coveragerc' => '.coveragerc'
=== removed file 'plainbox/test-with-coverage.sh'
--- plainbox/test-with-coverage.sh	2014-01-07 18:04:33 +0000
+++ plainbox/test-with-coverage.sh	1970-01-01 00:00:00 +0000
@@ -1,15 +0,0 @@
-#!/bin/sh
-# On recent enough Debian/Ubuntu you can run this with python3-coverage (or
-# python3.4-coverage) to run coverage with standard packages, without
-# virtualenv. Everywhere else the default 'coverage3' should work fine.
-#
-# Because python3-coverage is still broken
-rm -rf htmlcov
-coverage=${1:-coverage3}
-# Requires activated virtualenv with coverage
-$coverage run --branch $(which plainbox) self-test --unit-tests --fail-fast --quiet
-if [ "$1" != "--skip-integration" ]; then
-    $coverage run --append --branch $(which plainbox) self-test --integration-tests --fail-fast --quiet
-fi
-# coverage3 report
-$coverage html

=== added file 'support/test-with-coverage'
--- support/test-with-coverage	1970-01-01 00:00:00 +0000
+++ support/test-with-coverage	2014-02-24 20:36:43 +0000
@@ -0,0 +1,63 @@
+#!/bin/sh
+# This file is part of Checkbox.
+#
+# Copyright 2013 Canonical Ltd.
+# Written by:
+#   Zygmunt Krynicki <zygmunt.krynicki@canonical.com>
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+
+# Helper script to run coverage testing
+# =====================================
+
+# XXX: Requires activated virtualenv with coverage
+# It *may* work in other situations so this is not enforced
+
+# Disable all kinds of locale support
+export LANG=
+export LANGUAGE=
+export LC_ALL=C.UTF-8
+
+# On recent enough Debian/Ubuntu you can run this with python3-coverage (or
+# python3.4-coverage) to run coverage with standard packages, without
+# virtualenv. Everywhere else the default 'coverage3' should work fine.
+#
+# Because python3-coverage is still broken
+coverage=${1:-coverage3}
+
+# Run plainbox self-test, pass --after-reexec to fake the internal re-exec that
+# it performs (this seems to fail when invoked this way as it assumes it knows
+# to run plainbox self-test which we are not doing here)
+$coverage run --branch --module plainbox self-test \
+    --after-reexec \
+    --fail-fast \
+    --quiet \
+    --unit-tests
+
+# Run integrations tests as well, unless --skip-integration
+if [ "$1" != "--skip-integration" ]; then
+    $coverage run --append --branch $(which plainbox) self-test \
+        --after-reexec \
+        --integration-tests \
+        --fail-fast \
+        --quiet
+fi
+
+# Display the non-html report
+$coverage report
+
+# Generate the HTML report
+rm -rf htmlcov
+$coverage html
+echo "The HTML report is now ready in htmlcov" 

=== added symlink 'test-with-coverage'
=== target is 'support/test-with-coverage'
